Version 2.2
============

* Improved variable substitution for TestProgram().

* Add DParameter class.

* Add SimpleSweep() examples.

* Add SubmitHost(), support for hub's submit command.

Version 2.1
===========

* When experimental data is available, can perform Bayesian Calibration on input
  parameters.

* Added better scripting examples.
